@@ -56,7 +56,7 @@ class LinkOrCreatePatchOp(hook.DataOperationMixIn, hook.Operation):
                 revision = entity.rev
                 patch = self.session.create_entity(
                     'Patch', originator=revision.author, branch=revision.branch,
-                    patch_repository=revision.from_repository)
+                    patch_repository=revision.from_repository, patch_name=entity.file.path)
             patch.set_relations(patch_revision=entity)
             # patch file is being removed: mark it on the patch entity if still
             # active
@@ -246,6 +246,17 @@ class ReviewerSetHook(hook.Hook):
         self._cw.execute('SET P nosy_list U WHERE P eid %(p)s, U eid %(u)s, NOT P nosy_list U',
                          {'p': self.eidfrom, 'u': self.eidto})
 
+class UpdatePatchNameHook(hook.Hook):
+    __regid__ = 'vcreview.patch-name-update'
+    __select__ = hook.Hook.__select__ & hook.match_rtype('patch_revision')
+    events = ('after_add_relation',)
+
+    def __call__(self):
+        patch = self._cw.entity_from_eid(self.eidfrom)
+        versioncontent = self._cw.entity_from_eid(self.eidto)
+        if patch.patch_name != versioncontent.file.path:
+            patch.set_attributes(patch_name=versioncontent.file.path)
+
 from cubes.nosylist import hooks as nosylist
 nosylist.S_RELS |= set(('has_activity', 'patch_revision'))
 # XXX should add 'comments' relation in set below
