@@ -122,6 +122,19 @@ class patch_reviewer(RelationDefinition):
     constraints = [RQLConstraint('EXISTS(O in_group G, G name "reviewers") '
                                  'OR EXISTS(S patch_repository R, R repository_reviewer O)')]
 
+class patch_committer(RelationDefinition):
+    __permissions__ = {
+        'read': ('managers', 'users', 'guests'),
+        'add': ('managers', 'committers',
+                RRQLExpression('S patch_repository R, R repository_committer U')),
+        'delete': ('managers', 'committers',
+                   RRQLExpression('S patch_repository R, R repository_committer U')),
+        }
+    subject = 'Patch'
+    object = 'CWUser'
+    constraints = [RQLConstraint('EXISTS(O in_group G, G name "committers") '
+                                 'OR EXISTS(S patch_repository R, R repository_committer O)')]
+
 class patch_depends_on(RelationDefinition):
     subject = 'Patch'
     object = 'Patch'
