@@ -42,6 +42,7 @@ _afs = uicfg.autoform_section
 _pvs.tag_subject_of(('Patch', 'patch_repository', '*'), 'hidden') # in breadcrumbs
 _pvs.tag_subject_of(('Patch', 'patch_revision', '*'), 'hidden') # table in attributes
 _pvs.tag_subject_of(('Patch', 'patch_reviewer', '*'), 'attributes')
+_pvs.tag_subject_of(('Patch', 'patch_committer', '*'), 'attributes')
 _pvdc.tag_subject_of(('Patch', 'applied_at', '*'), {'vid': 'incontext'})
 
 class PatchPrimaryView(tabs.TabbedPrimaryView):
@@ -173,7 +174,7 @@ class RepositoryPatchesTable(EntityView):
     __regid__ = 'vcreview.repository.patches'
     __select__ = is_instance('Repository') & score_entity(lambda x: x.patchrepo_of)
 
-    rql = ('Any P,PO,P,PB,PS,COUNT(TR) GROUPBY P,PO,PB,PS WHERE '
+    rql = ('Any P,PO,P,P,PB,PS,COUNT(TR) GROUPBY P,PO,PB,PS WHERE '
            'P originator PO, P branch PB, P in_state PS, TR? wf_info_for P, '
            'P patch_repository R, R eid %(x)s')
 
